diff --git a/files/pips/openstack-integration-tests b/files/pips/tempest
similarity index 100%
rename from files/pips/openstack-integration-tests
rename to files/pips/tempest
diff --git a/stackrc b/stackrc
index 7da7258c6d..524cc99237 100644
--- a/stackrc
+++ b/stackrc
@@ -40,7 +40,7 @@ QUANTUM_REPO=https://github.com/openstack/quantum
 QUANTUM_BRANCH=master
 
 # CI test suite
-CITEST_REPO=https://github.com/openstack/openstack-integration-tests.git
+CITEST_REPO=https://github.com/openstack/tempest.git
 CITEST_BRANCH=master
 
 # Specify a comma-separated list of uec images to download and install into glance.
diff --git a/tools/build_uec_ramdisk.sh b/tools/build_uec_ramdisk.sh
index 0c27734135..3bd704ba9c 100755
--- a/tools/build_uec_ramdisk.sh
+++ b/tools/build_uec_ramdisk.sh
@@ -149,7 +149,7 @@ git_clone $NOVNC_REPO $DEST/novnc $NOVNC_BRANCH
 git_clone $HORIZON_REPO $DEST/horizon $HORIZON_BRANCH
 git_clone $NOVACLIENT_REPO $DEST/python-novaclient $NOVACLIENT_BRANCH
 git_clone $OPENSTACKX_REPO $DEST/openstackx $OPENSTACKX_BRANCH
-git_clone $CITEST_REPO $DEST/openstack-integration-tests $CITEST_BRANCH
+git_clone $CITEST_REPO $DEST/tempest $CITEST_BRANCH
 
 # Use this version of devstack
 rm -rf $MNT_DIR/$DEST/devstack
diff --git a/tools/build_ci_config.sh b/tools/build_ci_config.sh
index f627f43509..0e43aa4903 100755
--- a/tools/build_ci_config.sh
+++ b/tools/build_ci_config.sh
@@ -1,10 +1,10 @@
 #!/usr/bin/env bash
 #
 # build_ci_config.sh - Build a config.ini for openstack-integration-tests
 #                      (https://github.com/openstack/openstack-integration-tests)
 
 function usage {
-    echo "$0 - Build config.ini for openstack-integration-tests"
+    echo "$0 - Build config.ini for tempest"
     echo ""
     echo "Usage: $0 [configdir]"
     exit 1
@@ -49,7 +49,7 @@ source ./stackrc
 # Where Openstack code lives
 DEST=${DEST:-/opt/stack}
 
-CITEST_DIR=$DEST/openstack-integration-tests
+CITEST_DIR=$DEST/tempest
 
 CONFIG_DIR=${1:-$CITEST_DIR/etc}
 CONFIG_CONF=$CONFIG_DIR/storm.conf
@@ -90,7 +90,7 @@ function git_clone {
 }
 
 # Install tests and prerequisites
-sudo PIP_DOWNLOAD_CACHE=/var/cache/pip pip install --use-mirrors `cat $TOP_DIR/files/pips/openstack-integration-tests`
+sudo PIP_DOWNLOAD_CACHE=/var/cache/pip pip install --use-mirrors `cat $TOP_DIR/files/pips/tempest`
 
 git_clone $CITEST_REPO $CITEST_DIR $CITEST_BRANCH
 
@@ -1,10 +1,10 @@
 #!/usr/bin/env bash
 #
-# build_ci_config.sh - Build a config.ini for openstack-integration-tests
-#                      (https://github.com/openstack/openstack-integration-tests)
+# build_ci_config.sh - Build a config.ini for tempest (openstack-integration-tests)
+#                      (https://github.com/openstack/tempest.git)
 
 function usage {